    containers:

    	open container from an image archive:
    		[xonsh] docker container list
    		[xonsh] docker import EC_Book_4.tar
    		[xonsh] docker image tag 98859e57ca0f5e8a7652564597e1fd131441fbc8070d12211b2151ca7aba2682 elliptic_book_4:latest

    		xor:
    			[xonsh] docker run -it {image ID} /bin/bash
    			[xonsh] docker run -v /path_inside_host:/path_inside_container -it {image ID} /bin/bash

    	save container as image archive:
    		[xonsh] docker export --output="EC_Book_4.tar" {container ID}

    	push container to docker hub:
    		[xonsh] docker image tag 9fb4dc777fae bgrace2345/gitlab_pip_env:1
    		[xonsh] docker push bgrace2345/gitlab_pip_env:1

    	save changes to a container:
    		[xonsh]

    	delete:
    		[xonsh] docker container rm {CONTAINER ID}

    	delete every non-running container:
    		[xonsh] docker container prune -f

    	list every:
    		[xonsh] docker container list --all

    	list:
    		[xonsh] docker container list